@@ -6,8 +6,8 @@
 ;; Maintainer: Bozhidar Batsov <bozhidar@batsov.dev>
 ;; URL: http://github.com/bbatsov/neocaml
 ;; Keywords: languages ocaml ml
-;; Package-Version: 20260225.1322
-;; Package-Revision: 6ee2fcb1a9f1
+;; Package-Version: 20260226.920
+;; Package-Revision: 972723675651
 ;; Package-Requires: ((emacs "29.1"))
 
 ;; This file is not part of GNU Emacs.
@@ -855,7 +855,7 @@ was in a comment, nil otherwise to let the default handler run."
 ;;;; Comment continuation (M-j)
 
 (defun neocaml--comment-body-column ()
-  "Return the column where comment body text starts, or nil."
+  "Return the column of the comment body text start, or nil."
   (let* ((node (treesit-node-at (point)))
          (comment (treesit-parent-until
                    node
